"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var readline = require("readline");
var path = require("path");
var Queue_1 = require("../Queue");
var toJSON = function (csvFile, callback) {
    // Props
    var api, keys, jsonData = { data: [] };
    // Read csvFile line by line
    var readInterface = readline.createInterface({
        input: fs.createReadStream(csvFile),
        output: undefined
    });
    // Push argument (objectified) to jsonData object
    var collect = function (csv_data) {
        var record = {};
        csv_data = csv_data.values(); // turn into iterator
        Array.from(keys, function (key) {
            record[key] = csv_data.next().value;
        });
        jsonData['data'].push(record);
    };
    // Save data to file
    var defaultSaveOptions = {
        filename: csvFile,
        spaces: 1,
        prettify: false
    };
    var save = function (_a) {
        var _b = _a === void 0 ? defaultSaveOptions : _a, _c = _b.filename, filename = _c === void 0 ? csvFile : _c, _d = _b.prettify, prettify = _d === void 0 ? false : _d, _e = _b.spaces, spaces = _e === void 0 ? 1 : _e;
        var data;
        // Stringify data
        if (prettify) {
            data = JSON.stringify(jsonData.data, null, spaces);
        }
        else {
            data = JSON.stringify(jsonData.data);
        }
        // extract name from csv file to be used as new json file name
        var file = path.basename("" + filename, '.csv');
        // Write data to file
        fs.writeFile("./" + file + ".json", data, function (error) {
            if (error)
                throw error;
            console.log("> Done. New file [ " + file + ".json ] saved in current working directory");
        });
    };
    //* Read and enqueue data from csvFile
    readInterface.on('line', function (data) {
        Queue_1.default.enqueue(data.replace("\n", "").split(','));
    });
    //? Done Reading from csvFile?
    readInterface.on('close', function () {
        // Extract the first item from Queue, the column headers
        keys = Queue_1.default.dequeue();
        // Extract everything else from Queue 
        while (!Queue_1.default.is_empty())
            collect(Queue_1.default.dequeue());
        // Public API
        api = {
            data: jsonData.data,
            save: save
        };
        // Serve API as callback argument
        callback(api);
    });
};
exports.default = toJSON;
//# sourceMappingURL=to-json.js.map